@@ -104,6 +104,29 @@ static GObjectClass *parent_class;
 //#define DEBUG_PRINT(format_MACRO,...)           g_print (format_MACRO, ##__VA_ARGS__);
 #define DEBUG_PRINT(format_MACRO,...)             
 
+/* do not call brasero_*_start() at nautilus startup, they are very expensive;
+ * lazily initialize those instead */
+static void
+ensure_initialized()
+{
+	static gboolean initialized = FALSE;
+	GConfClient *client;
+
+	if (!initialized) {
+		client = gconf_client_get_default ();
+		if (gconf_client_get_bool (client, "/apps/brasero/nautilus-extension-debug", NULL)) {
+		    brasero_media_library_set_debug (TRUE);
+		    brasero_burn_library_set_debug (TRUE);
+		}
+		g_object_unref (client);
+
+		brasero_media_library_start ();
+		brasero_burn_library_start (NULL, NULL);
+
+		DEBUG_PRINT ("Libbrasero-media started\n");
+		initialized = TRUE;
+	}
+}
 
 static void
 launch_brasero_on_window_session (BraseroSessionCfg	*session,
@@ -111,7 +134,7 @@ launch_brasero_on_window_session (BraseroSessionCfg	*session,
 				  GtkWidget		*options,
 				  GtkWindow		*window)
 {
-	const gchar			*icon_name;
+	const gchar		*icon_name;
 	GtkWidget		*dialog;
 	GtkResponseType		 result;
 
@@ -136,7 +159,8 @@ launch_brasero_on_window_session (BraseroSessionCfg	*session,
 	result = gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_destroy (dialog);
 
-	if (result != GTK_RESPONSE_OK)
+	if (result != GTK_RESPONSE_OK
+	&&  result != GTK_RESPONSE_ACCEPT)
 		return;
 
 	/* now run burn dialog */
@@ -151,8 +175,13 @@ launch_brasero_on_window_session (BraseroSessionCfg	*session,
 
 	gtk_widget_show (dialog);
 	gtk_window_present (GTK_WINDOW (dialog));
-	brasero_burn_dialog_run (BRASERO_BURN_DIALOG (dialog),
-				 BRASERO_BURN_SESSION (session));
+
+	if (result == GTK_RESPONSE_OK)
+		brasero_burn_dialog_run (BRASERO_BURN_DIALOG (dialog),
+					 BRASERO_BURN_SESSION (session));
+	else
+		brasero_burn_dialog_run_multi (BRASERO_BURN_DIALOG (dialog),
+					       BRASERO_BURN_SESSION (session));
 
 	gtk_widget_destroy (dialog);
 }
@@ -307,6 +336,8 @@ write_iso_activate_cb (NautilusMenuItem *item,
         NautilusFileInfo	*file_info;
         char			*uri;
 
+	ensure_initialized();
+
         file_info = g_object_get_data (G_OBJECT (item), "file_info");
         uri = nautilus_file_info_get_uri (file_info);
 
@@ -329,6 +360,8 @@ copy_disc_activate_cb (NautilusMenuItem *item,
 	BraseroTrackDisc	*track;
 	BraseroDrive		*drive;
 
+	ensure_initialized();
+
         device_path = g_object_get_data (G_OBJECT (item), "drive_device_path");
 	monitor = brasero_medium_monitor_get_default ();
 	drive = brasero_medium_monitor_get_drive (monitor, device_path);
@@ -386,6 +419,8 @@ blank_disc_activate_cb (NautilusMenuItem *item,
 {
 	BraseroBlankDialog *dialog;
 
+	ensure_initialized();
+
 	dialog = brasero_blank_dialog_new ();
 	tool_dialog_run (BRASERO_TOOL_DIALOG (dialog),
 			 GTK_WINDOW (user_data),
@@ -585,6 +620,8 @@ nautilus_disc_burn_get_file_items (NautilusMenuProvider *provider,
 		BraseroMedia		 media;
 		BraseroTrackType	*type;
 
+		ensure_initialized();
+
                 device_path = g_volume_get_identifier (volume, G_VOLUME_IDENTIFIER_KIND_UNIX_DEVICE);
 		monitor = brasero_medium_monitor_get_default ();
 		bdrive = brasero_medium_monitor_get_drive (monitor, device_path);
@@ -979,22 +1016,7 @@ nautilus_disc_burn_register_type (GTypeModule *module)
 void
 nautilus_module_initialize (GTypeModule *module)
 {
-	GConfClient *client;
-
         DEBUG_PRINT ("Initializing nautilus-disc-recorder\n");
-
-	client = gconf_client_get_default ();
-	if (gconf_client_get_bool (client, "/apps/brasero/nautilus-extension-debug", NULL)) {
-		brasero_media_library_set_debug (TRUE);
-		brasero_burn_library_set_debug (TRUE);
-	}
-	g_object_unref (client);
-
-	brasero_media_library_start ();
-        brasero_burn_library_start (NULL, NULL);
-
-        DEBUG_PRINT ("Libbrasero-media started\n");
-
         nautilus_disc_burn_register_type (module);
 }
 
