@@ -159,7 +159,7 @@ static GtkActionEntry entries[] = {
 	 G_CALLBACK (brasero_audio_disc_edit_information_cb)},
 	{"DeleteAudio", GTK_STOCK_REMOVE, NULL, NULL, N_("Remove the selected files from the project"),
 	 G_CALLBACK (brasero_audio_disc_delete_activated_cb)},
-	{"PasteAudio", GTK_STOCK_PASTE, NULL, NULL, N_("Add the files stored in the clipboard"),
+	{"PasteAudio", NULL, N_("Paste files"), NULL, N_("Add the files stored in the clipboard"),
 	 G_CALLBACK (brasero_audio_disc_paste_activated_cb)},
 	{"Pause", "insert-pause", N_("I_nsert a Pause"), NULL, N_("Add a 2 second pause after the track"),
 	 G_CALLBACK (brasero_audio_disc_add_pause_cb)},
@@ -926,7 +926,6 @@ brasero_audio_disc_session_changed (BraseroSessionCfg *session,
 							   BRASERO_TRACK (track));
 
 			error = brasero_status_get_error (status);
-			g_print ("ERR %i\n", error->code);
 			if (!error)
 				brasero_audio_disc_file_type_error_dialog (self, uri);
 			else if (error->code == BRASERO_BURN_ERROR_FILE_FOLDER) {
